@@ -18,10 +18,10 @@ class Patterns(CollectionApi):
     remove_method   = 'remove_pattern'
     nullable_edits   = [ 'scale ']
 
-    def add(self, name, slots:list=None, rate=1, direction='forward', length=None):
+    def add(self, name, slots:list=None, scale=None, octave_shift=None, rate=1, direction='forward', length=None):
         params = locals()
         return self._generic_add(name, params)
 
-    def edit(self, name, new_name:str=None, slots:list=None, direction=None, length=None, pattern_type=None):
+    def edit(self, name, new_name:str=None, slots:list=None, scale=None, octave_shift=None, rate=None,  direction=None, length=None):
         params = locals()
         return self._generic_edit(name, params)
\ No newline at end of file
