@@ -10,7 +10,7 @@ from warpseq.api.interfaces.base import CollectionApi
 class Tracks(CollectionApi):
 
     object_class    = Track
-    public_fields   = [ 'name', 'instrument', 'track' ]
+    public_fields   = [ 'name', 'instruments', 'muted']
     song_collection = 'tracks'
     add_method      = 'add_tracks'
     add_required    = [ 'muted' ]
