@@ -39,4 +39,4 @@ class NewReferenceObject(BaseObject):
 
     @classmethod
     def from_dict(cls, song, data):
-        return load_object(cls, song, data)
+        return load_object(song, data)
