@@ -11,12 +11,9 @@ from ..playback.player import Player
 from ..utils import utils
 from .base import NewReferenceObject
 from .scale import Scale
-from warpseq.utils.serialization import Serializer
 from warpseq.model.context import Context
 from warpseq.model.event import Event, NOTE_ON
 
-import time
-
 # FAIR WARNING: some refactoring still pending
 
 DEFAULT_SCALE = None
@@ -36,13 +33,8 @@ class Clip(NewReferenceObject):
         '_scale_roller'
     ]
 
-    SERIALIZER = Serializer(
-        values = ( 'name', 'repeat', 'slot_length', 'next_clip', 'auto_scene_advance', 'tempo_shifts', 'rate' ),
-        objects = ( 'track', 'scene' ),
-        object_lists = ( 'patterns', 'scales' ),
-        objects_2d = ( 'transforms', ),
-        custom = ()
-    )
+    SAVE_AS_REFERENCES = [ 'track', 'scene', 'patterns', 'scales' ]
+
 
     def __init__(self, name=None, scales=None, patterns=None, transforms=None,  rate=1, repeat=-1,
                  auto_scene_advance=False, next_clip=None, tempo_shifts=None, track=None,
@@ -152,31 +144,30 @@ class Clip(NewReferenceObject):
 
     def _process_ties(self, chords):
 
-        previous_was_tie = False
         previous_chord = None
         tied = 0
+        previous_was_tie = False
 
         for (i, slot) in enumerate(chords):
 
-            if i == 0 and (slot and len(slot.notes) and not slot.notes[0].tie):
-                previous_chord = slot
-
-            is_tie = False
-            if slot and len(slot.notes) and slot.notes[0].tie:
-                is_tie = True
-
-            if is_tie:
+            if slot and len(slot.notes) and slot.notes[0].tie and previous_chord:
                 tied = tied + 1
 
-            if not is_tie:
-                if previous_was_tie:
-                    previous_chord.with_tied(previous_chord.notes[0].length * tied)
+            if previous_was_tie and previous_chord and ((not slot) or (slot and len(slot.notes) and not slot.notes[0].tie)):
+                previous_chord.with_tied(tied * previous_chord.notes[0].length)
+                previous_chord = None
                 tied = 0
 
-            previous_was_tie = is_tie
+            previous_was_tie = False
 
-            if slot and len(slot.notes) and not slot.notes[0].tie:
-                previous_chord = slot
+            if slot and len(slot.notes):
+                if not slot.notes[0].tie:
+                    previous_chord = slot
+                else:
+                    previous_was_tie = True
+
+        if previous_was_tie and previous_chord:
+            previous_chord.with_tied(tied * previous_chord.notes[0].length)
 
 
 
@@ -229,7 +220,6 @@ class Clip(NewReferenceObject):
                                 events.append(event2)
 
 
-
         return events
 
     # ==================================================================================================================
@@ -259,6 +249,8 @@ class Clip(NewReferenceObject):
 
         chords = []
 
+        # BOOKMARK: this is the part that will have to nest if we do drum patterns
+
         for expression in pattern.get_iterator():
 
             root = scale.get_first().copy()
@@ -319,5 +311,3 @@ class Clip(NewReferenceObject):
         )
         player.engine.player = player
         return player
-
-
