@@ -10,21 +10,14 @@
 from .base import NewReferenceObject
 from warpseq.api.exceptions import *
 from warpseq.model.directions import *
-from warpseq.utils.serialization import Serializer
 from warpseq.model.slot import Slot, DataSlot
 
 class DataPool(NewReferenceObject, Directionable):
 
-    __slots__ = [ 'name', 'slots', 'current_slots', 'direction', 'current_direction', 'length',
+    __slots__ = [ 'name', 'slots', '_current_slots', 'direction', '_current_direction', 'length',
                   '_iterator', 'obj_id' ]
 
-    SERIALIZER = Serializer(
-        values = ( 'name', 'direction', 'length'),
-        objects = ( ),
-        object_lists = (),
-        objects_2d = (),
-        custom = ( 'slots' ),
-    )
+    SAVE_AS_REFERENCES = [ 'slots' ]
 
     def __init__(self, name=None, slots=None, direction=FORWARD, length=None, obj_id=None):
 
@@ -38,7 +31,7 @@ class DataPool(NewReferenceObject, Directionable):
             raise InvalidInput("direction must be one of: %s" % DIRECTIONS)
 
         self.direction = direction
-        self.current_direction = direction
+        self._current_direction = direction
         self.obj_id = obj_id
 
         if length is None:
@@ -49,9 +42,3 @@ class DataPool(NewReferenceObject, Directionable):
         super(DataPool, self).__init__()
         self.reset()
 
-    #def get_length(self):
-    #    return self.length
-
-    #def get_iterator(self):
-    #    #for _ in range(0, self.get_length()):
-    #    yield next(self._iterator)
