@@ -35,12 +35,14 @@ class Note(object):
 
     __slots__ = ( 'name', 'octave', 'tie', 'length', 'start_time', 'end_time', 'velocity', 'from_scale',
                   'from_parser', 'repeat', 'length_mod', 'tied', 'delay', 'no_shift', 'muted', 'track_copy',
-                  'ccs', 'deferred_expressions', 'from_context')
+                  'ccs', 'deferred_expressions', 'from_context', 'octave_set_recorded', 'octave_shifts_recorded', 'degree_shifts_recorded')
+
+    SAVE_AS_REFERENCES = []
 
     def __init__(self, name=None, octave=0, tie=False, length=None, start_time=None, end_time=None,
                  velocity=DEFAULT_VELOCITY, from_scale=None, from_parser=None, repeat=None, length_mod=1, tied=0, delay=0,
                  no_shift=False, muted=False, track_copy=None, ccs=None, deferred_expressions=None,
-                 from_context=None):
+                 from_context=None, octave_set_recorded=None, octave_shifts_recorded=0, degree_shifts_recorded=0):
 
          if name in EQUIVALENCE_SET:
              name = NOTES[EQUIVALENCE.index(name)]
@@ -61,6 +63,10 @@ class Note(object):
          self.delay = delay
          self.muted = muted
          self.from_context = from_context
+         # needed to process deferred track grabs
+         self.octave_set_recorded = octave_set_recorded
+         self.octave_shifts_recorded = octave_shifts_recorded
+         self.degree_shifts_recorded = degree_shifts_recorded
 
          if ccs is None:
              ccs = {}
@@ -73,6 +79,15 @@ class Note(object):
              track_copy = []
          self.track_copy = track_copy
 
+    def to_dict(self):
+        # this is only used by serializing the scale root
+        return dict(name=self.name, octave=self.octave)
+
+    @classmethod
+    def from_dict(self, data):
+        # this is only used by deserializing the scale root
+        return Note(name=data['name'], octave=data['octave'])
+
     def copy(self):
         """
         Returns a new Note with the same data as the current Note
@@ -95,7 +110,10 @@ class Note(object):
                     track_copy = self.track_copy[:],
                     ccs = self.ccs,
                     deferred_expressions = self.deferred_expressions[:],
-                    from_context = self.from_context
+                    from_context = self.from_context,
+                    octave_shifts_recorded = self.octave_shifts_recorded,
+                    degree_shifts_recorded = self.degree_shifts_recorded,
+                    octave_set_recorded = self.octave_set_recorded
         )
 
     def get_parser(self):
@@ -120,6 +138,16 @@ class Note(object):
         # how many milliseconds should we add from ties marked after this note?
         return self.tied
 
+    def record_octave_set(self, value):
+        self.octave_set_recorded = value
+        self.octave_shifts_recorded = 0
+
+    def record_octave_shift(self, value):
+        self.octave_shifts_recorded = self.octave_shifts_recorded + value
+
+    def record_degree_shift(self, value):
+        self.degree_shifts_recorded = self.degree_shifts_recorded + value
+
     def with_tied(self, amount):
         self.tied = amount
         return self
@@ -223,18 +251,18 @@ class Note(object):
         return n1
 
     def __repr__(self):
-        if self.tie:
-            return "n<TIE>"
-        elif self.muted:
-            return "n<MUTED>"
         # FIXME: this will be simplified once we are doing less note debugging
-        return "n<%s|%s,len=%s,time=%s/%s,cc=%s>" % (
+        return "Note<%s|%s,len=%s,time=%s/%s,cc=%s,tie=%s,muted=%s,track_copy=%s,def=%s,tied=%s>" % (
             self.name,
             self.octave,
             self.length,
             self.start_time,
             self.end_time,
             self.ccs,
+            self.tie,
+            self.muted,
+            [x.name for x in self.track_copy],
+            self.deferred_expressions,
+            self.tied
         )
 
-
