@@ -4,9 +4,11 @@
 # Apache2 Licensed
 # ------------------------------------------------------------------
 
-from warpseq.model.evaluator import Evaluator, set_variable
+from warpseq.model.evaluator import *
 from warpseq.model.note import Note
 from warpseq.model.registers import get_first_playing_note
+import warpseq.utils.serialization as serialization
+
 
 
 def evaluate(context=None, subject=None, how=None):
@@ -33,14 +35,17 @@ class BaseSlot(object):
 
 class DataSlot(BaseSlot):
 
-    __slots__ = ('value')
+    SAVE_AS_REFERENCES = []
+
+    __slots__ = ('value',)
 
     def __init__(self, value=None):
         self.value = value
 
-
 class Slot(BaseSlot):
 
+    SAVE_AS_REFERENCES = []
+
     __slots__ = ( "note", "octave", "degree", "repeats", "length", "sharp", "flat", "chord_type", "inversion",
         "variables", "track_copy", "track_grab", "rest", "ccs", "delay", "velocity", "skip", "shuffle",
         "reverse", "reset", "tie", "degree_shift", "octave_shift" )
@@ -162,16 +167,20 @@ class Slot(BaseSlot):
         if self.octave is not None:
             res = evaluate(context=context, subject=note, how=self.octave)
             note = note.with_octave(res)
+            note.record_octave_set(res)
 
         # -----
         # NOTE MODIFICATIONS HERE
 
         if self.octave_shift is not None:
-            res = evaluate(context=context, subject=note, how=self.octave_shift)
-            note = note.transpose(octaves=res)
+            how = evaluate(context=context, subject=note, how=self.octave_shift)
+            note = note.transpose(octaves=how)
+            note.record_octave_shift(how)
 
         if self.degree_shift is not None:
-            note = note.scale_transpose(context.scale, evaluate(context=context, subject=note, how=self.degree_shift))
+            how = evaluate(context=context, subject=note, how=self.degree_shift)
+            note = note.scale_transpose(context.scale, how)
+            note.record_degree_shift(how)
 
         if self.repeats:
             note = note.with_repeat(evaluate(context=context, subject=note, how=self.repeats))
@@ -234,6 +243,20 @@ def defer_track_grab(context=None, track=None, subject=None, how=None):
     copy_tracks = playing.track_copy
     if copy_tracks and track not in copy_tracks:
         return None
-    return subject.replace_with_note(playing.name, playing.octave)
+
+    new_note = subject.replace_with_note(playing.name, playing.octave)
+
+    if new_note is None:
+        return new_note
+
+    first = subject
+    if first.octave_set_recorded is not None:
+        new_note = subject.with_octave(first.octave_set_recorded)
+    new_note = subject.transpose(octaves=first.octave_shifts_recorded)
+    if playing.from_scale:
+        new_note = subject.scale_transpose(playing.from_scale, first.degree_shifts_recorded)
+
+    return new_note
+
 
 S = Slot
\ No newline at end of file
