@@ -9,19 +9,12 @@
 
 from .base import NewReferenceObject
 from .instrument import Instrument
-from warpseq.utils.serialization import Serializer
 
 class Track(NewReferenceObject):
 
     __slots__ = [ 'name', 'muted', 'instrument', 'instruments', 'clip_ids', 'obj_id' ]
 
-    SERIALIZER = Serializer(
-        values = ( 'name', 'muted', 'clip_ids' ),
-        objects = ( 'instrument' ),
-        object_lists = ( 'instruments' ),
-        objects_2d = (),
-        custom=(),
-    )
+    SAVE_AS_REFERENCES = [ 'instruments', 'instrument' ]
 
     def __init__(self, name=None, muted=False, instrument=None, instruments=None, clip_ids=None, obj_id=None):
 
@@ -32,14 +25,15 @@ class Track(NewReferenceObject):
         if instruments is None:
             instruments = []
         self.instruments = instruments
+        self.instrument = instrument
 
         if clip_ids is None:
             clip_ids = []
         self.clip_ids = clip_ids
 
         # backwards compat: new usage should use "instruments"
-        if instrument is not None:
-            self.instruments.append(instrument)
+        if self.instrument is not None:
+            self.instruments.append(self.instrument)
 
         super(Track, self).__init__()
 
