@@ -50,9 +50,13 @@ def open_port(device_name):
 
 
 def midi_note_on(out, channel, note_number, velocity):
+    if not note_number:
+        return
     out.send_message([MIDI_NOTE_ON | channel - 1, note_number, velocity])
 
 def midi_note_off(out, channel, note_number, velocity):
+    if not note_number:
+        return
     out.send_message([MIDI_NOTE_OFF | channel - 1, note_number, velocity])
 
 def _channel_message(out, command, channel, *data):
